@@ -645,7 +645,12 @@ public class InterlevelScene extends PixelScene {
 			Level level = Dungeon.newLevel();
 			Dungeon.switchLevel( level, -1 );
 		} else {
-			Mob.holdAllies( Dungeon.level );
+			if (curTransition.destBranch != Dungeon.branch && Dungeon.depth >= 16 && Dungeon.depth <= 20) {
+				//FIXME avoids holding allies when entering city quest area, this is very sloppy though
+				// perhaps holding allies could be a property of the transition?
+			} else {
+				Mob.holdAllies(Dungeon.level);
+			}
 			Dungeon.saveAll();
 
 			Level level;
@@ -684,7 +689,12 @@ public class InterlevelScene extends PixelScene {
 	}
 
 	private void ascend() throws IOException {
-		Mob.holdAllies( Dungeon.level );
+		if (curTransition.destBranch != Dungeon.branch && Dungeon.depth >= 16 && Dungeon.depth <= 20) {
+			//FIXME avoids holding allies when entering city quest area, this is very sloppy though
+			// perhaps holding allies could be a property of the transition?
+		} else {
+			Mob.holdAllies(Dungeon.level);
+		}
 		Dungeon.saveAll();
 
 		Level level;
